Documentation
¶
Overview ¶
Package api is the internal version of the API. +groupName=incidents.monitoring.appscode.com
Index ¶
Constants ¶
const GroupName = "incidents.monitoring.appscode.com"
Variables ¶
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: runtime.APIVersionInternal}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func RegisterDefaults ¶
RegisterDefaults adds defaulters functions to the given scheme. Public to allow building arbitrary schemes. All generated defaulters are covering - they call all nested defaulters.
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns back a Group qualified GroupResource
Types ¶
type Acknowledgement ¶
type Acknowledgement struct {
metav1.TypeMeta
metav1.ObjectMeta
Request AcknowledgementRequest
Response AcknowledgementResponse
}
func (*Acknowledgement) DeepCopy ¶
func (in *Acknowledgement) DeepCopy() *Acknowledgement
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Acknowledgement.
func (*Acknowledgement) DeepCopyInto ¶
func (in *Acknowledgement) DeepCopyInto(out *Acknowledgement)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Acknowledgement) DeepCopyObject ¶
func (in *Acknowledgement) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type AcknowledgementRequest ¶
type AcknowledgementRequest struct {
// Comment by user
Comment string
// Skip sending notification
// +optional
SkipNotify bool
}
func (*AcknowledgementRequest) DeepCopy ¶
func (in *AcknowledgementRequest) DeepCopy() *AcknowledgementRequest
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AcknowledgementRequest.
func (*AcknowledgementRequest) DeepCopyInto ¶
func (in *AcknowledgementRequest) DeepCopyInto(out *AcknowledgementRequest)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AcknowledgementResponse ¶
type AcknowledgementResponse struct {
// The time at which the acknowledgement was done.
// +optional
Timestamp metav1.Time
}
func (*AcknowledgementResponse) DeepCopy ¶
func (in *AcknowledgementResponse) DeepCopy() *AcknowledgementResponse
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AcknowledgementResponse.
func (*AcknowledgementResponse) DeepCopyInto ¶
func (in *AcknowledgementResponse) DeepCopyInto(out *AcknowledgementResponse)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.